==> 5.7.0.tar.gz: hugo-theme-relearn/exampleSite/content/_index.en.md <==
+++
archetype = "home"
title = "Hugo Relearn Theme"
+++

The [Relearn theme](http://github.com/McShelby/hugo-theme-relearn) is a theme for [Hugo](https://gohugo.io/), a static website generator written in Go. Where Hugo is often used for blogs, this theme is designed with documentation in mind.

{{% notice info %}}
The theme is a fork of the great [Learn theme](https://github.com/matcornic/hugo-theme-learn) with the aim of fixing long outstanding bugs and adepting to latest Hugo features. As far as possible this theme tries to be a drop-in replacement for the Learn theme.
{{% /notice %}}

## Main features

{{% notice tip %}}
See [what's new]({{% relref "basics/migration" %}}) within the latest update.
{{% /notice %}}

- Usable offline, no external dependencies
- Usable without a HTTP server from the file system
- Support for Internet Explorer 11
- Responsive design
- Configurable hidden pages
- Automatic next/prev buttons to navigate through menu entries
- [Automatic Search]({{%relref "basics/configuration#activate-search" %}})
- [Dedicated search page]({{%relref "basics/configuration#activate-dedicated-search-page" %}})
- [Print]({{%relref "basics/configuration#activate-print-support" %}}) whole chapters or even the complete site
- [Multilingual mode]({{%relref "cont/i18n" %}}) for English, Arabic, Simplified Chinese, Traditional Chinese, Dutch, Finnish (Suomi), French, German, Hindi, Indonesian, Italian, Japanese, Korean, Polish, Portuguese, Russian, Spanish, Turkish, Vietnamese
- Support for languages written right to left
- [Unrestricted menu configuration]({{%relref "cont/menushortcuts" %}}) relating to amount of items and level of nesting
- [Font Awesome icons]({{%relref "cont/icons" %}})
- [Tagging support]({{%relref "cont/tags" %}})
- [Image resizing, shadow...]({{%relref "cont/markdown#images" %}})
- [Syntax highlighting]({{%relref "cont/syntaxhighlight" %}})
- [Attachments files]({{%relref "shortcodes/attachments" %}})
- [List child pages]({{%relref "shortcodes/children" %}})
- [Math and chemical formulae]({{%relref "shortcodes/math" %}}) using the MathJax library
- [Mermaid diagrams]({{%relref "shortcodes/mermaid" %}}) for flowcharts, sequences, gantts, pie, etc.
- [Swagger UI]({{%relref "shortcodes/swagger" %}}) for OpenAPI Specifications
- [Customizable look and feel]({{%relref "basics/customization"%}})
- [Predefined (light, dark) and customizable color variants]({{%relref "basics/generator" %}})
- [Buttons]({{%relref "shortcodes/button" %}})
- [Tip/Note/Info/Warning boxes]({{%relref "shortcodes/notice" %}})
- [Expand]({{%relref "shortcodes/expand" %}})
- [Tabs]({{%relref "shortcodes/tabs" %}})
- [File inclusion]({{%relref "shortcodes/include" %}})

## Getting support

To get support, feel free to open a new [discussion topic](https://github.com/McShelby/hugo-theme-relearn/discussions) or [issue](https://github.com/McShelby/hugo-theme-relearn/issues) in the official repository on GitHub.

## Become a contributor

Feel free to update this documentation by just clicking the **Edit** link displayed on top right of each page. Your changes will be deployed automatically once they were reviewed.

You are most welcome to contribute bugfixes or even new features to the source code by making pull requests to the [official repository](https://github.com/McShelby/hugo-theme-relearn) via GitHub. Please visit the [contribution guidelines](https://github.com/McShelby/hugo-theme-relearn/blob/main/.github/contributing.md) first.

## License

This theme is licensed under the [MIT License](https://github.com/McShelby/hugo-theme-relearn/blob/main/LICENSE).

## Credits

This theme would not be possible without the work of many others. See the [credits]({{%relref "more/credits" %}}) for a detailed list.

==> 5.9.4.tar.gz: hugo-theme-relearn/exampleSite/content/_index.en.md <==
+++
archetype = "home"
title = "Hugo Relearn Theme"
+++

The [Relearn theme](https://github.com/McShelby/hugo-theme-relearn) is a theme for [Hugo](https://gohugo.io/), a static website generator written in Go. Where Hugo is often used for blogs, this theme is designed with documentation in mind.

{{% notice info %}}
The theme is a fork of the great [Learn theme](https://github.com/matcornic/hugo-theme-learn) with the aim of fixing long outstanding bugs and adepting to latest Hugo features. As far as possible this theme tries to be a drop-in replacement for the Learn theme.
{{% /notice %}}

## Features

{{% notice tip %}}
See [What's New]({{% relref "basics/migration" %}}) within the latest update.
{{% /notice %}}

- Usable offline, no external dependencies
- Usable without a HTTP server from the file system
- Support for Internet Explorer 11
- Responsive design
- Configurable hidden pages
- Automatic next/prev buttons to navigate through menu entries
- [Automatic Search]({{%relref "basics/configuration#activate-search" %}})
- [Dedicated search page]({{%relref "basics/configuration#activate-dedicated-search-page" %}})
- [Support for GFM]({{% relref "cont/markdown" %}}) (GitHub Flavored Markdown)
- [Print]({{%relref "basics/configuration#activate-print-support" %}}) whole chapters or even the complete site
- [Multilingual mode]({{%relref "cont/i18n" %}}) for English, Arabic, Simplified Chinese, Traditional Chinese, Dutch, Finnish (Suomi), French, German, Hindi, Indonesian, Italian, Japanese, Korean, Polish, Portuguese, Russian, Spanish, Turkish, Vietnamese
- Support for languages written right to left
- [Unrestricted menu configuration]({{%relref "cont/menushortcuts" %}}) relating to amount of items and level of nesting
- [Font Awesome icons]({{%relref "shortcodes/icon" %}})
- [Tagging support]({{%relref "cont/tags" %}})
- [Image styling]({{%relref "cont/markdown#images" %}}) like sizing, shadow, border and alignment
- [Syntax highlighting]({{%relref "cont/syntaxhighlight" %}})
- [Customizable look and feel]({{%relref "basics/customization"%}})
- [Predefined (light, dark) and customizable color variants]({{%relref "basics/generator" %}})
- [Attachments files]({{%relref "shortcodes/attachments" %}})
- [List child pages]({{%relref "shortcodes/children" %}})
- [Math and chemical formulae]({{%relref "shortcodes/math" %}}) using the MathJax library
- [Mermaid diagrams]({{%relref "shortcodes/mermaid" %}}) for flowcharts, sequences, gantts, pie, etc.
- [Swagger UI]({{%relref "shortcodes/swagger" %}}) for OpenAPI Specifications
- [Badges]({{%relref "shortcodes/badge" %}})
- [Buttons]({{%relref "shortcodes/button" %}})
- [Tip/Note/Info/Warning boxes]({{%relref "shortcodes/notice" %}})
- [Expand]({{%relref "shortcodes/expand" %}})
- [Tabs]({{%relref "shortcodes/tabs" %}})
- [File inclusion]({{%relref "shortcodes/include" %}})

## Getting Support

To get support, feel free to open a new [discussion topic](https://github.com/McShelby/hugo-theme-relearn/discussions) or [issue report](https://github.com/McShelby/hugo-theme-relearn/issues) in the official repository on GitHub.

## Become a Contributor

Feel free to update this documentation by just clicking the {{% button style="transparent" icon="pen" %}}{{% /button %}} button displayed on top right of each page. Your changes will be deployed automatically once they were reviewed.

You are most welcome to contribute bugfixes or even new features to the source code by making pull requests to the [official repository](https://github.com/McShelby/hugo-theme-relearn) via GitHub. Please visit the [contribution guidelines](https://github.com/McShelby/hugo-theme-relearn/blob/main/.github/contributing.md) first.

## License

This theme is licensed under the [MIT License](https://github.com/McShelby/hugo-theme-relearn/blob/main/LICENSE).

## Credits

This theme would not be possible without the work of many others. See the [credits]({{%relref "more/credits" %}}) for a detailed list.
